package es.verdnatura.presentation.view.feature.articulo.fragment



import android.content.Intent
import android.content.SharedPreferences
import android.view.View
import android.view.inputmethod.EditorInfo
import androidx.lifecycle.Observer
import androidx.recyclerview.widget.LinearLayoutManager
import es.verdnatura.R
import es.verdnatura.databinding.FragmentItemCardBinding
import es.verdnatura.presentation.base.BaseFragment
import es.verdnatura.presentation.common.OnItemCardRowClickListener
import es.verdnatura.presentation.common.addFragment
import es.verdnatura.presentation.common.loadUrl
import es.verdnatura.presentation.view.component.CustomDialog
import es.verdnatura.presentation.view.feature.articulo.adapter.ItemCardAdapter
import es.verdnatura.presentation.view.feature.articulo.model.ItemCardRowVO
import es.verdnatura.presentation.view.feature.articulo.model.ItemCardVO
import es.verdnatura.presentation.view.feature.imageview.activity.ImageViewActivity
import es.verdnatura.presentation.view.feature.main.activity.MainActivity
import kotlinx.android.synthetic.main.activity_main.*
import kotlinx.android.synthetic.main.fragment_item_card.*
import kotlinx.android.synthetic.main.toolbar.*

class ItemCardFragment : BaseFragment<FragmentItemCardBinding,ItemCardViewModel>(ItemCardViewModel::class) {

    private var urlLarge:String = ""
    private var titleImage:String = ""

    companion object {
        fun newInstance() = ItemCardFragment()
    }
    private lateinit var customDialog: CustomDialog

    override fun getLayoutId(): Int = R.layout.fragment_item_card

    override fun init() {
        itemcard_layout.visibility = View.GONE
        activity!!.main_bottom_navigation.visibility = View.GONE
        setEvents()
        toolbar_title.text = "ItemCard"
        customDialog = CustomDialog(requireContext())
        super.init()
    }


    private fun setEvents(){
        edit_itemFk.requestFocus()
        edit_itemFk.setOnEditorActionListener { v, actionId, event ->
            if (actionId == EditorInfo.IME_ACTION_SEARCH || actionId == EditorInfo.IME_ACTION_DONE || actionId == 0) {
                if (!edit_itemFk.text.toString().isNullOrEmpty())
                    getItemCard(edit_itemFk.text.toString())
                edit_itemFk.setText("")
                (activity as MainActivity).hideKeyboard(edit_itemFk)
                return@setOnEditorActionListener true
            }
            false
        }


        backButton.setOnClickListener {
            activity!!.onBackPressed()
        }

        itemcard_image.setOnClickListener {
            val i:Intent = Intent(activity,ImageViewActivity::class.java)
            i.putExtra("url",urlLarge)
            i.putExtra("title",titleImage)
            startActivity(i)
        }
    }

    private fun getItemCard(itemFk:String){
        val prefs: SharedPreferences = activity!!.getSharedPreferences(PREFS_USER,0)
        val user = prefs.getString(USER,"")
        val password = prefs.getString(PASSWORD,"")
        val warehouseFk = prefs.getInt(WAREHOUSEFK,1).toString()
        splash_progress.visibility = View.VISIBLE
        viewModel.getItemCard(itemFk,warehouseFk,user!!,password!!)
    }

    override fun observeViewModel() {
        with(viewModel){
            itemcard.observe(viewLifecycleOwner, Observer {
                splash_progress.visibility = View.GONE
                if (it.isError){
                    itemcard_layout.visibility = View.GONE
                    toolbar_title.text = "ItemCard"
                    customDialog.setTitle("Error").setDescription(it.errorMessage).setOkButton("Cerrar"){
                        customDialog.hide()
                    }.show()
                }else{
                    if (it.id != "0"){
                        itemcard_layout.visibility = View.VISIBLE
                        setItemCard(it)
                    }else{
                        itemcard_layout.visibility = View.GONE
                        toolbar_title.text = "ItemCard"
                        customDialog.setTitle("Sin resultados").setDescription("No hemos podido encontrar el articulo. Revisa el sector.").setOkButton("Cerrar"){
                            customDialog.hide()
                        }.show()
                    }

                }
            })
        }
    }

    private fun setItemCard(itemInfo:ItemCardVO){
        toolbar_title.text = itemInfo.id+"-"+itemInfo.longName
        titleImage = itemInfo.id+"-"+itemInfo.longName
        itemcard_image.setImageDrawable(resources.getDrawable(R.drawable.loadphoto,resources.newTheme()))
        itemcard_image.loadUrl(itemInfo.urlImage200)
        urlLarge = itemInfo.urlImage
        itemcard_tag1.text = itemInfo.size
        itemcard_tag2.text = itemInfo.value5
        itemcard_tag3.text = itemInfo.value6
        itemcard_tag4.text = itemInfo.value7 + " " + itemInfo.origin
        val listItemsRow:ArrayList<ItemCardRowVO> = ArrayList()
        listItemsRow.add(ItemCardRowVO(title = "Total",value = itemInfo.total,isEditable = false))
        listItemsRow.add(ItemCardRowVO(title = "Disponible",value = itemInfo.available,isEditable = false))
        listItemsRow.add(ItemCardRowVO(title = "Ubicado",value = itemInfo.enAltillo,isEditable = false))
        //EDITABLES

        listItemsRow.add(ItemCardRowVO(title = "SIN UBICAR",value = itemInfo.enNicho,isEditable = true))
        listItemsRow.add(ItemCardRowVO(title = "NICHO",value = itemInfo.nicho,isEditable = true))
        listItemsRow.add(ItemCardRowVO(title = "RESERVA",value = itemInfo.reserva,isEditable = true))
        listItemsRow.add(ItemCardRowVO(title = "GROUPING",value = itemInfo.grouping,isEditable = true))
        listItemsRow.add(ItemCardRowVO(title = "PACKING",value = itemInfo.packing,isEditable = true))
        listItemsRow.add(ItemCardRowVO(title = "MINIMO",value = itemInfo.min,isEditable = true))
        listItemsRow.add(ItemCardRowVO(title = "BARCODE",barcodes = itemInfo.barcodes,isEditable = true))

        itemcard_recyclerview.adapter = ItemCardAdapter(listItemsRow,object: OnItemCardRowClickListener{
            override fun onItemCardRowClickListener(item: ItemCardRowVO) {
                customDialog.setTitle(item.title!!).setDescription(item.value!!).setOkButton("Cerrar"){
                    customDialog.hide()
                }.show()
            }
        })
        itemcard_recyclerview.layoutManager = LinearLayoutManager(requireContext(), LinearLayoutManager.VERTICAL, false)

        scroll_view.post(Runnable {
            val position:IntArray = IntArray(2)
            itemcard_image.getLocationInWindow(position)
            scroll_view.scrollTo(0, position[1])

        })



    }


}
